# DGA Intel

Using deep learning to detect DGA domains.

# Overview
The DGAIntel Python module allows you to utilize a powerful CNN-LSTM model to predict whether a given domain name was generated by a domain generation algorithm (DGA) or corresponds to a genuine domain. The prediction features are also accesible through [this website](http://www.dgaintel.com/), but this package allows for direct integration into your workflow.

# Usage

Here, we will go through using DGA Intel.

## Requirements

DGAIntel is designed for use with Python 3 only. It has only two requirements:

    - TensorFlow
    - Numpy

## Installation

To download dgaintel, simply use Pypi via pip.
```sh
$ pip install dgaintel
```
<!-- 
Verify your installation worked by running
```Python
>>> import dgaintel
>>> dgaintel.get_prediction('microsoft.com')
``` -->

## Using it
First, import DGAIntel.

```Python
import dgaintel
```

Now, to get the predicted probability of a domain name being DGA, simply run

```Python
dgaintel.get_prediction('<DOMAIN NAME>')
```

That's all there is to it!
